@@ -2,13 +2,12 @@
 
 module Doorkeeper
   class ApplicationController <
-    Doorkeeper.configuration.base_controller.constantize
-
+    Doorkeeper.config.resolve_controller(:base)
     include Helpers::Controller
 
-    unless Doorkeeper.configuration.api_only
+    unless Doorkeeper.config.api_only
       protect_from_forgery with: :exception
-      helper 'doorkeeper/dashboard'
+      helper "doorkeeper/dashboard"
     end
   end
 end
