@@ -2,7 +2,7 @@
 
 module Doorkeeper
   class ApplicationsController < Doorkeeper::ApplicationController
-    layout 'doorkeeper/admin' unless Doorkeeper.configuration.api_only
+    layout "doorkeeper/admin" unless Doorkeeper.configuration.api_only
 
     before_action :authenticate_admin!
     before_action :set_application, only: %i[show edit update destroy]
@@ -19,7 +19,7 @@ module Doorkeeper
     def show
       respond_to do |format|
         format.html
-        format.json { render json: @application, as_owner: true }
+        format.json { render json: @application }
       end
     end
 
@@ -32,15 +32,20 @@ module Doorkeeper
 
       if @application.save
         flash[:notice] = I18n.t(:notice, scope: %i[doorkeeper flash applications create])
+        flash[:application_secret] = @application.plaintext_secret
 
         respond_to do |format|
           format.html { redirect_to oauth_application_url(@application) }
-          format.json { render json: @application, as_owner: true }
+          format.json { render json: @application }
         end
       else
         respond_to do |format|
           format.html { render :new }
-          format.json { render json: { errors: @application.errors.full_messages }, status: :unprocessable_entity }
+          format.json do
+            errors = @application.errors.full_messages
+
+            render json: { errors: errors }, status: :unprocessable_entity
+          end
         end
       end
     end
@@ -49,22 +54,26 @@ module Doorkeeper
 
     def update
       if @application.update(application_params)
-        flash[:notice] = I18n.t(:notice, scope: %i[doorkeeper flash applications update])
+        flash[:notice] = I18n.t(:notice, scope: i18n_scope(:update))
 
         respond_to do |format|
           format.html { redirect_to oauth_application_url(@application) }
-          format.json { render json: @application, as_owner: true }
+          format.json { render json: @application }
         end
       else
         respond_to do |format|
           format.html { render :edit }
-          format.json { render json: { errors: @application.errors.full_messages }, status: :unprocessable_entity }
+          format.json do
+            errors = @application.errors.full_messages
+
+            render json: { errors: errors }, status: :unprocessable_entity
+          end
         end
       end
     end
 
     def destroy
-      flash[:notice] = I18n.t(:notice, scope: %i[doorkeeper flash applications destroy]) if @application.destroy
+      flash[:notice] = I18n.t(:notice, scope: i18n_scope(:destroy)) if @application.destroy
 
       respond_to do |format|
         format.html { redirect_to oauth_applications_url }
@@ -82,5 +91,9 @@ module Doorkeeper
       params.require(:doorkeeper_application)
         .permit(:name, :redirect_uri, :scopes, :confidential)
     end
+
+    def i18n_scope(action)
+      %i[doorkeeper flash applications] << action
+    end
   end
 end
