@@ -3,10 +3,10 @@
 module Doorkeeper
   class TokenInfoController < Doorkeeper::ApplicationMetalController
     def show
-      if doorkeeper_token && doorkeeper_token.accessible?
+      if doorkeeper_token&.accessible?
         render json: doorkeeper_token, status: :ok
       else
-        error = OAuth::ErrorResponse.new(name: :invalid_request)
+        error = OAuth::InvalidTokenResponse.new
         response.headers.merge!(error.headers)
         render json: error.body, status: error.status
       end
