@@ -9,10 +9,10 @@ module Doorkeeper
 
       def authorization
         env = __getobj__.env
-        env['HTTP_AUTHORIZATION'] ||
-          env['X-HTTP_AUTHORIZATION'] ||
-          env['X_HTTP_AUTHORIZATION'] ||
-          env['REDIRECT_X_HTTP_AUTHORIZATION']
+        env["HTTP_AUTHORIZATION"] ||
+          env["X-HTTP_AUTHORIZATION"] ||
+          env["X_HTTP_AUTHORIZATION"] ||
+          env["REDIRECT_X_HTTP_AUTHORIZATION"]
       end
     end
   end
