@@ -4,7 +4,11 @@ module Doorkeeper
   module Models
     module Scopes
       def scopes
-        OAuth::Scopes.from_string(self[:scopes])
+        OAuth::Scopes.from_string(scopes_string)
+      end
+
+      def scopes=(value)
+        super Array(value).join(" ")
       end
 
       def scopes_string
