@@ -1,10 +1,12 @@
+# frozen_string_literal: true
+
 module Doorkeeper
   module OAuth
     class Client
       Credentials = Struct.new(:uid, :secret) do
         class << self
           def from_request(request, *credentials_methods)
-            credentials_methods.inject(nil) do |credentials, method|
+            credentials_methods.inject(nil) do |_, method|
               method = self.method(method) if method.is_a?(Symbol)
               credentials = Credentials.new(*method.call(request))
               break credentials unless credentials.blank?
