@@ -4,20 +4,20 @@ module Doorkeeper
   module OAuth
     class ClientCredentialsRequest < BaseRequest
       class Issuer
-        attr_accessor :token, :validation, :error
+        attr_accessor :token, :validator, :error
 
-        def initialize(server, validation)
+        def initialize(server, validator)
           @server = server
-          @validation = validation
+          @validator = validator
         end
 
         def create(client, scopes, creator = Creator.new)
-          if validation.valid?
+          if validator.valid?
             @token = create_token(client, scopes, creator)
             @error = :server_error unless @token
           else
             @token = false
-            @error = validation.error
+            @error = validator.error
           end
           @token
         end
@@ -28,7 +28,7 @@ module Doorkeeper
           context = Authorization::Token.build_context(
             client,
             Doorkeeper::OAuth::CLIENT_CREDENTIALS,
-            scopes
+            scopes,
           )
           ttl = Authorization::Token.access_token_expires_in(@server, context)
 
@@ -36,7 +36,7 @@ module Doorkeeper
             client,
             scopes,
             use_refresh_token: false,
-            expires_in: ttl
+            expires_in: ttl,
           )
         end
       end
