@@ -7,12 +7,12 @@ module Doorkeeper
       attr_reader :response
       attr_writer :issuer
 
-      alias_method :error_response, :response
+      alias error_response response
 
       delegate :error, to: :issuer
 
       def issuer
-        @issuer ||= Issuer.new(server, Validation.new(server, self))
+        @issuer ||= Issuer.new(server, Validator.new(server, self))
       end
 
       def initialize(server, client, parameters = {})
