@@ -1,16 +1,18 @@
+# frozen_string_literal: true
+
 class HomeController < ApplicationController
   def index; end
 
   def sign_in
     session[:user_id] = if Rails.env.development?
-                          User.first || User.create!(name: 'Joe', password: 'sekret')
+                          User.first || User.create!(name: "Joe", password: "sekret")
                         else
                           User.first
                         end
-    redirect_to '/'
+    redirect_to "/"
   end
 
   def callback
-    render plain: 'ok'
+    render plain: "ok"
   end
 end
