@@ -1,11 +1,13 @@
+# frozen_string_literal: true
+
 class SemiProtectedResourcesController < ApplicationController
   before_action :doorkeeper_authorize!, only: :index
 
   def index
-    render plain: 'protected index'
+    render plain: "protected index"
   end
 
   def show
-    render plain: 'non protected show'
+    render plain: "non protected show"
   end
 end
