@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # Be sure to restart your server when you modify this file.
 
 # Your secret key for verifying the integrity of signed cookies.
@@ -5,4 +7,4 @@
 # Make sure the secret is at least 30 characters and all random,
 # no regular words or you'll be exposed to dictionary attacks.
 Dummy::Application.config.secret_key_base =
-  'c00157b5a1bb6181792f0f4a8a080485de7bab9987e6cf159'
+  "c00157b5a1bb6181792f0f4a8a080485de7bab9987e6cf159"
