@@ -1,12 +1,14 @@
-require 'spec_helper'
-require 'grape'
-require 'rack/test'
-require 'doorkeeper/grape/helpers'
+# frozen_string_literal: true
+
+require "spec_helper"
+require "grape"
+require "rack/test"
+require "doorkeeper/grape/helpers"
 
 # Test Grape API application
 module GrapeApp
   class API < Grape::API
-    version 'v1', using: :path
+    version "v1", using: :path
     format :json
     prefix :api
 
@@ -17,7 +19,7 @@ module GrapeApp
         doorkeeper_authorize!
       end
 
-      desc 'Protected resource, requires token.'
+      desc "Protected resource, requires token."
 
       get :status do
         { token: doorkeeper_token.token }
@@ -29,10 +31,10 @@ module GrapeApp
         doorkeeper_authorize!
       end
 
-      desc 'Protected resource, requires token with scopes (defined in endpoint).'
+      desc "Protected resource, requires token with scopes (defined in endpoint)."
 
       get :status, scopes: [:admin] do
-        { response: 'OK' }
+        { response: "OK" }
       end
     end
 
@@ -41,10 +43,10 @@ module GrapeApp
         doorkeeper_authorize! :admin
       end
 
-      desc 'Protected resource, requires token with scopes (defined in helper).'
+      desc "Protected resource, requires token with scopes (defined in helper)."
 
       get :status do
-        { response: 'OK' }
+        { response: "OK" }
       end
     end
 
@@ -52,13 +54,13 @@ module GrapeApp
       desc "Public resource, no token required."
 
       get :status do
-        { response: 'OK' }
+        { response: "OK" }
       end
     end
   end
 end
 
-describe 'Grape integration' do
+describe "Grape integration" do
   include Rack::Test::Methods
 
   def app
@@ -70,66 +72,66 @@ describe 'Grape integration' do
   end
 
   let(:client) { FactoryBot.create(:application) }
-  let(:resource) { FactoryBot.create(:doorkeeper_testing_user, name: 'Joe', password: 'sekret') }
+  let(:resource) { FactoryBot.create(:doorkeeper_testing_user, name: "Joe", password: "sekret") }
   let(:access_token) { client_is_authorized(client, resource) }
 
-  context 'with valid Access Token' do
-    it 'successfully requests protected resource' do
+  context "with valid Access Token" do
+    it "successfully requests protected resource" do
       get "api/v1/protected/status.json?access_token=#{access_token.token}"
 
       expect(last_response).to be_successful
 
-      expect(json_body['token']).to eq(access_token.token)
+      expect(json_body["token"]).to eq(access_token.token)
     end
 
-    it 'successfully requests protected resource with token that has required scopes (Grape endpoint)' do
-      access_token = client_is_authorized(client, resource, scopes: 'admin')
+    it "successfully requests protected resource with token that has required scopes (Grape endpoint)" do
+      access_token = client_is_authorized(client, resource, scopes: "admin")
 
       get "api/v1/protected_with_endpoint_scopes/status.json?access_token=#{access_token.token}"
 
       expect(last_response).to be_successful
-      expect(json_body).to have_key('response')
+      expect(json_body).to have_key("response")
     end
 
-    it 'successfully requests protected resource with token that has required scopes (Doorkeeper helper)' do
-      access_token = client_is_authorized(client, resource, scopes: 'admin')
+    it "successfully requests protected resource with token that has required scopes (Doorkeeper helper)" do
+      access_token = client_is_authorized(client, resource, scopes: "admin")
 
       get "api/v1/protected_with_helper_scopes/status.json?access_token=#{access_token.token}"
 
       expect(last_response).to be_successful
-      expect(json_body).to have_key('response')
+      expect(json_body).to have_key("response")
     end
 
-    it 'successfully requests public resource' do
+    it "successfully requests public resource" do
       get "api/v1/public/status.json"
 
       expect(last_response).to be_successful
-      expect(json_body).to have_key('response')
+      expect(json_body).to have_key("response")
     end
   end
 
-  context 'with invalid Access Token' do
-    it 'fails without access token' do
+  context "with invalid Access Token" do
+    it "fails without access token" do
       get "api/v1/protected/status.json"
 
       expect(last_response).not_to be_successful
-      expect(json_body).to have_key('error')
+      expect(json_body).to have_key("error")
     end
 
-    it 'fails for access token without scopes' do
+    it "fails for access token without scopes" do
       get "api/v1/protected_with_endpoint_scopes/status.json?access_token=#{access_token.token}"
 
       expect(last_response).not_to be_successful
-      expect(json_body).to have_key('error')
+      expect(json_body).to have_key("error")
     end
 
-    it 'fails for access token with invalid scopes' do
-      access_token = client_is_authorized(client, resource, scopes: 'read write')
+    it "fails for access token with invalid scopes" do
+      access_token = client_is_authorized(client, resource, scopes: "read write")
 
       get "api/v1/protected_with_endpoint_scopes/status.json?access_token=#{access_token.token}"
 
       expect(last_response).not_to be_successful
-      expect(json_body).to have_key('error')
+      expect(json_body).to have_key("error")
     end
   end
 end
