@@ -1,11 +1,13 @@
-require 'spec_helper'
+# frozen_string_literal: true
+
+require "spec_helper"
 
 describe Doorkeeper do
   describe "#authenticate" do
     let(:request) { double }
 
     it "calls OAuth::Token#authenticate" do
-      token_strategies = Doorkeeper.configuration.access_token_methods
+      token_strategies = Doorkeeper.config.access_token_methods
 
       expect(Doorkeeper::OAuth::Token).to receive(:authenticate)
         .with(request, *token_strategies)
