@@ -1,11 +1,13 @@
-require 'coveralls'
+# frozen_string_literal: true
 
-Coveralls.wear!('rails') do
-  add_filter('/spec/')
-  add_filter('/lib/generators/doorkeeper/templates/')
+require "coveralls"
+
+Coveralls.wear!("rails") do
+  add_filter("/spec/")
+  add_filter("/lib/generators/doorkeeper/templates/")
 end
 
-ENV['RAILS_ENV'] ||= 'test'
+ENV["RAILS_ENV"] ||= "test"
 
 $LOAD_PATH.unshift File.dirname(__FILE__)
 
@@ -13,26 +15,23 @@ require "#{File.dirname(__FILE__)}/support/doorkeeper_rspec.rb"
 
 DOORKEEPER_ORM = Doorkeeper::RSpec.detect_orm
 
-require 'dummy/config/environment'
-require 'rspec/rails'
-require 'capybara/rspec'
-require 'database_cleaner'
-require 'generator_spec/test_case'
+require "dummy/config/environment"
+require "rspec/rails"
+require "capybara/rspec"
+require "database_cleaner"
+require "generator_spec/test_case"
 
 # Load JRuby SQLite3 if in that platform
 if defined? JRUBY_VERSION
-  require 'jdbc/sqlite3'
+  require "jdbc/sqlite3"
   Jdbc::SQLite3.load_driver
 end
 
 Doorkeeper::RSpec.print_configuration_info
 
-# Remove after dropping support of Rails 4.2
-require "#{File.dirname(__FILE__)}/support/http_method_shim.rb"
-
 require "support/orm/#{DOORKEEPER_ORM}"
 
-Dir["#{File.dirname(__FILE__)}/support/{dependencies,helpers,shared}/*.rb"].each { |file| require file }
+Dir["#{File.dirname(__FILE__)}/support/{dependencies,helpers,shared}/*.rb"].sort.each { |file| require file }
 
 RSpec.configure do |config|
   config.infer_spec_type_from_file_location!
@@ -51,5 +50,5 @@ RSpec.configure do |config|
     DatabaseCleaner.clean
   end
 
-  config.order = 'random'
+  config.order = "random"
 end
