@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # load schema to in memory sqlite
 ActiveRecord::Migration.verbose = false
-load Rails.root + 'db/schema.rb'
+load Rails.root + "db/schema.rb"
